
# messages
msg_no_output = "When outpath not indicated, it will use inputpath as default.\
                 \nPlease Type [Y]es/[N]o/[Outpath]/[P]rint(Default Yes):\n"
msg_passwd = "enter pasword: "
msg_file_not_found = "file doesn't exist."

# symbols
yes_symbols = ['y','Y']
no_symbols = ['n','N']
print_symbols = ['p','P']
int_symbols = ['i','I']